# Copyright (C) 2004 by Intevation GmbH
# Authors:
# Jan-Oliver Wagner <jan@intevation.de>
#
# This program is free software under the GPL (>=v2)
# Read the file COPYING coming with Thuban for details.

"""
Registry for Extensions.

This module defines a registry for Extensions.
This is basically used for displaying information on
the active Extensions in the general About-Dialog.
A registration is not mandatory to make a Extension
work, but any Extension should register to provide
a complete information in the Thuban About Dialog.

A Extension should define a ThubanExtensionDesc object
and apply ext_registry.Add() to register it.
"""

__version__ = "$Revision$"
# $Source$
# $Id$

class ThubanExtensionDesc:

    """
    A description of a Thuban Extension.
    """

    def __init__(self, name, version, authors, copyright, desc,
                 min_thuban_versions):
        """
        Initialize a new Thuban Extension information.

        name -- The name of the Thuban Extension.
                Example: 'gns2shp'

        version -- The version number of the Thuban Extension.
                   Example: '1.0.0'

        authors -- List of authors.
                   Example: [ 'Jan-Oliver Wagner' ]

        copyright -- Copyright notice.
                     Example: '2003, 2004 Intevation GmbH'

        desc -- Short description of the Thuban Extension.
                Example: _('''
                         Converts GNS (Geographical Name Service of NIMA)
                         to Shapefile format and displays the data.
                         ''')
 
        min_thuban_versions -- Minimum Thuban versions required to
                               run the extension. This is a dictionary
                               where the major release numbers ('X.Y')
                               are the keys and the minor release
                               number is the contents (e.g. 'Z').
                               Example: { '1.0' : '0' }
        """
        self.name = name
        self.version = version
        self.authors = authors
        self.copyright = copyright
        self.desc = desc
        self.min_thuban_versions = min_thuban_versions

class ThubanExtensionRegistry:

    """
    A ThubanExtensionRegistry keeps information on the registered
    Thuban Extensions.

    The registry will raise a exception either when the version
    required for the Extensions exceeds the version of the currently
    running Thuban or if the name of a registered extension already
    is used for registering another extension.
    """

    def __init__(self):
        self.registry = []

    def Add(self, ext):
        self.registry.append(ext)

    def Get(self):
        return self.registry


# The central Thuban Extensions registry
ext_registry = ThubanExtensionRegistry()
